RunLengthFilter class

RunLengthDecode (7.4.5): length byte 0–127 copies the next length+1 bytes literally; 129–255 repeats the next byte 257−length times; 128 is EOD.

Inheritance

Constructors

RunLengthFilter()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

decode(Uint8List data, CosDictionary? params) Uint8List
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited