TimeStampVerification class

The outcome of verifying a timestamp token against the data it stamps.

Constructors

TimeStampVerification({required bool imprintMatches, required bool signatureValid, required DateTime? genTime, String? problem})

Properties

genTime DateTime?
The trusted time the token asserts.
final
hashCode int
The hash code for this object.
no setterinherited
imprintMatches bool
The token's MessageImprint equals the digest of the timestamped data.
final
problem String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signatureValid bool
The TSA's CMS signature over the TSTInfo verifies.
final
valid bool
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited