Universal tag numbers this library cares about.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
Constants
- bitString → const int
- bmpString → const int
- generalizedTime → const int
- ia5String → const int
- integer → const int
- nullValue → const int
- octetString → const int
- oid → const int
- printableString → const int
- sequence → const int
- set → const int
- t61String → const int
- utcTime → const int
- utf8String → const int